/*******************************************************************************
* File Name: Comp_PM.c  
* Version 1.80
*
*  Description:
*     This file provides the power management source code APIs for the
*     Comparator.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include "Comp.h"

static Comp_backupStruct Comp_backup;


/*******************************************************************************
* Function Name: Comp_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void Comp_SaveConfig(void)
{
    /* Empty since all are system reset for retention flops */
}


/*******************************************************************************
* Function Name: Comp_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void Comp_RestoreConfig(void)
{
    /* Empty since all are system reset for retention flops */    
}


/*******************************************************************************
* Function Name: Comp_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Comp_backup.enableState:  Is modified depending on the enable 
*   state of the block before entering sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Comp_Sleep(void)
{
    /* Save Comp's enable state */    
    if(Comp_ACT_PWR_EN == (Comp_PWRMGR & Comp_ACT_PWR_EN))
    {
        /* Comp is enabled */
        Comp_backup.enableState = 1u;
    }
    else
    {
        /* Comp is disabled */
        Comp_backup.enableState = 0u;
    }    
    
    Comp_Stop();
    Comp_SaveConfig();
}


/*******************************************************************************
* Function Name: Comp_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Comp_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Comp_Wakeup(void) 
{
    Comp_RestoreConfig();
    
    if(Comp_backup.enableState == 1u)
    {
        /* Enable Comp's operation */
        Comp_Enable();

    } /* Do nothing if Comp was disabled before */    
    
}


/* [] END OF FILE */
