/*******************************************************************************
* File Name: ISR_Compare.c  
* Version 1.50
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <ISR_Compare.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START ISR_Compare_intc` */
#include "PWM_Window.h"
#include "Counter.h"
#include <project.h>

uint8 compare_occured = 0;

/* `#END` */


/*******************************************************************************
* Function Name: ISR_Compare_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_Compare_Start(void)
{
    /* For all we know the interrupt is active. */
    ISR_Compare_Disable();

    /* Set the ISR to point to the ISR_Compare Interrupt. */
    ISR_Compare_SetVector(ISR_Compare_Interrupt);

    /* Set the priority. */
    ISR_Compare_SetPriority(ISR_Compare_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISR_Compare_Enable();
}

/*******************************************************************************
* Function Name: ISR_Compare_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_Compare_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    ISR_Compare_Disable();

    /* Set the ISR to point to the ISR_Compare Interrupt. */
    ISR_Compare_SetVector(address);

    /* Set the priority. */
    ISR_Compare_SetPriority(ISR_Compare_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISR_Compare_Enable();
}

/*******************************************************************************
* Function Name: ISR_Compare_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_Compare_Stop(void) 
{
    /* Disable this interrupt. */
    ISR_Compare_Disable();
}

/*******************************************************************************
* Function Name: ISR_Compare_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for ISR_Compare.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(ISR_Compare_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START ISR_Compare_Interrupt` */

	/* Read the PWM_Window Status register to clear the interrupt bits */
	PWM_Window_ReadStatusRegister();
	
	/* Set the flag to 1 to indicate the occurence of interrupt */
	compare_occured = 1;
	
    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (ISR_Compare__ES2_PATCH ))      
            ISR_Compare_ISR_PATCH();
        #endif
    #endif
}

/*******************************************************************************
* Function Name: ISR_Compare_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling ISR_Compare_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use ISR_Compare_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_Compare_SetVector(cyisraddress address) 
{
    CY_SET_REG16(ISR_Compare_INTC_VECTOR, (uint16) address);
}

/*******************************************************************************
* Function Name: ISR_Compare_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress ISR_Compare_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(ISR_Compare_INTC_VECTOR);
}

/*******************************************************************************
* Function Name: ISR_Compare_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling ISR_Compare_Start
*   or ISR_Compare_StartEx will override any effect this method would have had. 
*	This method should only be called after ISR_Compare_Start or 
*	ISR_Compare_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_Compare_SetPriority(uint8 priority) 
{
    *ISR_Compare_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: ISR_Compare_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 ISR_Compare_GetPriority(void) 
{
    uint8 priority;


    priority = *ISR_Compare_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: ISR_Compare_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_Compare_Enable(void) 
{
    /* Enable the general interrupt. */
    *ISR_Compare_INTC_SET_EN = ISR_Compare__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_Compare_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 ISR_Compare_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*ISR_Compare_INTC_SET_EN & ISR_Compare__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: ISR_Compare_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_Compare_Disable(void) 
{
    /* Disable the general interrupt. */
    *ISR_Compare_INTC_CLR_EN = ISR_Compare__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_Compare_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_Compare_SetPending(void) 
{
    *ISR_Compare_INTC_SET_PD = ISR_Compare__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_Compare_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_Compare_ClearPending(void) 
{
    *ISR_Compare_INTC_CLR_PD = ISR_Compare__INTC_MASK;
}
#if 0 /* begin disabled code */
`#start ISR_PWMCompare_Interrupt` -- section removed from template
	
	/* Call the ReadStatusRegister to clear the Interrupt Status bit */
	PWM_Window_ReadStatusRegister();
	
	/* Set the flag to indicate occurence of the interrupt */
	compare_occured = 1;
	
`#end`

#endif /* end disabled code */
